; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| AIR}h |------------------------------------------------------

[Command]
name = "AI1"
command = a, a, a, a, a, a, a, a, a
time = 1

[Command]
name = "AI2"
command = a, a, a, a, a, a, a, a, b
time = 1

[Command]
name = "AI3"
command = a, a, a, a, a, a, a, a, c
time = 1

[Command]
name = "AI4"
command = a, a, a, a, a, a, a, a, z
time = 1

[Command]
name = "AI5"
command = a, a, a, x, a, a, x, a, c
time = 1

[Command]
name = "AI6"
command = a, z, a, y, a, a, a, a, z
time = 1

[Command]
name = "AI7"
command = a, a, a, b, a, b, a, a, a
time = 1

[Command]
name = "AI8"
command = a, c, c, a, a, a, a, a, b
time = 1

[Command]
name = "AI9"
command = a, b, a, a, z, z, a, a, c
time = 1

[Command]
name = "AI10"
command = a, a, b, z, a, z, b, a, z
time = 1

[Command]
name = "AI11"
command = a, a, a, y, a, z, x, a, c
time = 1

[Command]
name = "AI12"
command = a, z, b, y, z, a, a, a, z
time = 1

[Command]
name = "AI13"
command = a, z, z, x, z, a, x, a, a
time = 1

[Command]
name = "AI14"
command = b, c, a, x, a, c, c, a, b
time = 1

[Command]
name = "AI15"
command = a, a, z, x, a, z, a, y, c
time = 1

[Command]
name = "AI16"
command = a, y, y, y, y, y, y, a, z
time = 1

[Command]
name = "AI17"
command = a, z, z, x, a, a, x, z, z
time = 1

[Command]
name = "AI18"
command = a, z, a, y, y, a, x, a, z
time = 1

[Command]
name = "AI19"
command = a, a, y, b, b, b, b, b, b
time = 1

[Command]
name = "AI20"
command = a, c, x, a, b, c, a, a, b
time = 1

[Command]
name = "AI21"
command = a, b, z, a, z, z, a, a, c
time = 1

[Command]
name = "AI22"
command = a, z, z, z, a, z, b, a, z
time = 1

[Command]
name = "AI23"
command = a, x, a, y, a, z, x, a, c
time = 1

[Command]
name = "AI24"
command = a, z, b, y, z, a, x, a, z
time = 1

[Command]
name = "AI25"
command = a, a, x, x, c, c, z, z, a
time = 1

[Command]
name = "AI26"
command = z, x, a, z, a, a, a, a, z
time = 1

[Command]
name = "AI27"
command = z, a, z, x, a, x, a, y, c
time = 1

[Command]
name = "AI28"
command = a, y, y, a, x, z, a, z, b
time = 1

[Command]
name = "AI29"
command = a, y, a, x, a, y, x, z, c
time = 1

[Command]
name = "AI30"
command = y, z, y, y, z, z, a, z, b
time = 1

[Command]
name = "AI31"
command = a, a, a, b, a, b, z, a, a
time = 1

[Command]
name = "AI32"
command = a, c, c, a, a, z, a, a, b
time = 1

[Command]
name = "AI33"
command = a, b, a, c, y, z, a, a, c
time = 1

[Command]
name = "AI34"
command = a, a, b, z, a, z, b, a, y
time = 1

[Command]
name = "AI35"
command = a, a, c, y, a, z, x, a, c
time = 1

[Command]
name = "AI36"
command = a, z, b, y, z, y, c, a, y
time = 1

[Command]
name = "AI37"
command = a, z, z, x, z, a, x, y, a
time = 1

[Command]
name = "AI38"
command = b, c, a, x, a, c, c, a, b
time = 1

[Command]
name = "AI39"
command = a, y, z, x, a, z, a, y, c
time = 1

[Command]
name = "AI40"
command = a, y, y, x, y, y, y, a, x
time = 1

[Command]
name = "AI41"
command = a, z, z, x, a, z, x, y, c
time = 1

[Command]
name = "AI42"
command = a, z, a, y, c, a, c, a, c
time = 1

[Command]
name = "AI43"
command = a, a, y, b, b, c, b, b, c
time = 1

[Command]
name = "AI44"
command = a, c, x, z, b, c, z, a, z
time = 1

[Command]
name = "AI45"
command = a, b, z, a, y, z, a, y, c
time = 1

[Command]
name = "AI46"
command = a, z, z, y, a, z, b, a, x
time = 1

[Command]
name = "AI47"
command = a, x, c, c, a, z, y, a, c
time = 1

[Command]
name = "AI48"
command = a, z, b, y, z, a, x, a, x
time = 1

[Command]
name = "AI49"
command = a, x, c, x, a, z, x, a, z
time = 1

[Command]
name = "AI50"
command = a, z, b, y, z, c, x, a, y
time = 1
;-| Special Motions |------------------------------------------------------

[Command]
name = "Va"
command = ~D, DB, B, DB, D, DF, F, y
time = 40

[Command]
name = "Va"
command = ~D, B, DB, D, DF, F, y
time = 40

[Command]
name = "Va"
command = ~D, DB, B, D, DF, F, y
time = 40

[Command]
name = "Va"
command = ~D, B, D, F, y
time = 40

[Command]
name = "Va"
command = ~D, DB, B, DB, D, DF, y
time = 40

[Command]
name = "Va"
command = ~DB, B, DB, D, DF, y
time = 40

[Command]
name = "Va"
command = ~DB, B, DB, D, DF, F, y
time = 40

[Command]
name = "Va"
command = ~DB, B, D, F, y
time = 40

[Command]
name = "Va"
command = ~DB, B, D, DF, y
time = 40



[Command]
name = ""
command = ~D, DB, B, D, DB, B, x
time = 40

[Command]
name = "VA"
command = ~D, DF, F, D, DF, F, y
time = 40

[Command]
name = "Aa"
command = ~D, DF, F, D, DF, F, x
time = 40


[Command]
name = "ECh"
command = ~D, DF, F, x
time = 20

[Command]
name = "ECh"
command = ~D, DF, F, y
time = 20

[Command]
name = "\jbNGbW"
command = ~B, F, B, x
time = 30

[Command]
name = "\jbNGbW"
command = ~B, F, B, y
time = 30


[Command]
name = "o[XgNbV"
command = ~D, D, x
time = 20


[Command]
name = "o[XgNbV"
command = ~D, D, y
time = 20

[Command]
name = "CWO\[h"
command = ~B, DB, D, x
time = 20

[Command]
name = "CWO\[h"
command = ~B, DB, D, y
time = 20


[Command]
name = "_uA^bN"
command = ~D, DB, B, x
time = 20

[Command]
name = "_uA^bNQ"
command = ~D, DB, B, y
time = 20

[Command]
name = "_uA^bNR"
command = ~D, DB, B, a
time = 20

[Command]
name = "󂯗"
command = ~F, B, F, a
time = 20

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b


[Command]
name = "Stand Throw"
command = F, x

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1


[Command]
name = "Middle"
command = b
time = 1


[Command]
name = "y"
command = y
time = 1

[Command]
name = "holdx";Required (do not remove)
command = /$x
time = 1

[Command]
name = "holdy";Required (do not remove)
command = /$y
time = 1


[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holdstart";Required (do not remove)
command = /$s
time = 1

[command]
name="fwd"
command=F
time=1
[command]
name="back"
command=B
time=1
[command]
name="up"
command=U
time=1
[command]
name="down"
command=D
time=1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]



;---------------------------------------------------------------------------
;
[State -1, Va]
type = ChangeState
value = 3200
triggerall = var(59) <= 0
triggerall = command = "Va"
triggerall = power = 4000
triggerall = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;
[State -1, ]
type = ChangeState
value = 3100
triggerall = var(59) <= 0
triggerall = command = ""
triggerall = power >= 3000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit
trigger4 = Stateno = [1000,1150]
trigger4 = moveHit

;---------------------------------------------------------------------------
;
[State -1, VA]
type = ChangeState
value = 2300
triggerall = var(59) <= 0
triggerall = command = "VA"
triggerall = power >= 2000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit
trigger4 = Stateno = [1000,1150]
trigger4 = moveHit

;---------------------------------------------------------------------------
;
[State -1, Aa]
type = ChangeState
value = 2200
triggerall = var(59) <= 0
triggerall = command = "Aa"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit
trigger4 = Stateno = [1000,1150]
trigger4 = moveHit


;---------------------------------------------------------------------------
[State -1,\jbNGbW]
type = ChangeState
value = 1050
triggerall = var(59) <= 0
triggerall = command = "\jbNGbW"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit

;---------------------------------------------------------------------------
[State -1,ECh]
type = ChangeState
value = 1000
triggerall = var(59) <= 0
triggerall = command = "ECh"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit

;---------------------------------------------------------------------------
[State -1,ECh]
type = ChangeState
value = 1010
triggerall = var(59) <= 0
triggerall = command = "ECh"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit

;---------------------------------------------------------------------------
[State -1,_uA^bN]
type = ChangeState
value = 1100
triggerall = var(59) <= 0
triggerall = command = "_uA^bN"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit

;---------------------------------------------------------------------------
[State -1,_uA^bNQ]
type = ChangeState
value = 1110
triggerall = var(59) <= 0
triggerall = command = "_uA^bNQ"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit

;---------------------------------------------------------------------------
[State -1,_uA^bNR]
type = ChangeState
value = 1120
triggerall = var(59) <= 0
triggerall = command = "_uA^bNR"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit


;---------------------------------------------------------------------------
[State -1,o[XgNbV]
type = ChangeState
value = 1150
triggerall = var(59) <= 0
triggerall = command = "o[XgNbV"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit

;---------------------------------------------------------------------------
[State -1,CWO\[h]
type = ChangeState
value = 1200
triggerall = var(59) <= 0
triggerall = command = "CWO\[h"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = Stateno = 200 || Stateno = 210 || Stateno = 230 || Stateno = 240
trigger2 = moveHit
trigger3 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger3 = moveHit

;---------------------------------------------------------------------------
[State -1,󂯗]
type = ChangeState
value = 900
triggerall = var(59) <= 0
triggerall = command = "󂯗"
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = var(59) <= 0
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = var(59) <= 0
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(59) <= 0
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 8

;---------------------------------------------------------------------------
;Stand Strong Punch
;
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = var(59) <= 0
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 12

;---------------------------------------------------------------------------
;Stand Light Kick
;
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = var(59) <= 0
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 4

;---------------------------------------------------------------------------
;
;Q[W
[State -1, Taunt]
type = ChangeState
value = 196
triggerall = command = "start"
triggerall = Power < 4000
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎ
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = var(59) <= 0
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊݒ
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = var(59) <= 0
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400)
trigger2 = (time > 6) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Light Kick
;Ⴊ݋
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = var(59) <= 0
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) && time > 6
trigger3 = (stateno = 410) && time > 10

;---------------------------------------------------------------------------
;󒆎
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(59) <= 0
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = var(59) <= 0
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(59) <= 0
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking
trigger3 = stateno = 600 || stateno = 610 ;jump_x or jump_a
trigger3 = movecontact

;
;ȉAIGAIpǋLꏊ
;

[State -1, AI]
type = VarSet
TriggerAll = Var(59) <= 0
TriggerAll = RoundState = [1,2]
trigger1  = (Command = "AI1") || (Command = "AI2") || (Command = "AI3") 
trigger2  = (Command = "AI4") || (Command = "AI5") || (Command = "AI6") || (Command = "AI7")
trigger3  = (Command = "AI8") || (Command = "AI9") || (Command = "AI10") || (Command = "AI11") || (Command = "AI12") || (Command = "AI13") || (Command = "AI14") || (Command = "AI15")
trigger4  = (Command = "AI16") || (Command = "AI17") || (Command = "AI18") || (Command = "AI19") || (Command = "AI20") || (Command = "AI21") || (Command = "AI22") || (Command = "AI23")
trigger5  = (Command = "AI24") || (Command = "AI25") || (Command = "AI26") || (Command = "AI27") || (Command = "AI28") || (Command = "AI29") || (Command = "AI30") || (Command = "AI31")
trigger6 = (Command = "AI32") || (Command = "AI33") || (Command = "AI34") || (Command = "AI35") || (Command = "AI36") || (Command = "AI37") || (Command = "AI38") || (Command = "AI39")
trigger7 = (Command = "AI40") || (Command = "AI41") || (Command = "AI42") || (Command = "AI43") || (Command = "AI44") || (Command = "AI45") || (Command = "AI46") || (Command = "AI47")
trigger8 = (Command = "AI48") || (Command = "AI49") || (Command = "AI50")
;----------------------------------------------------------------
Trigger9 = 1 ;AI펞N@؂Ƃ͐擪; 
;----------------------------------------------------------------
var(59) = 1;̒lύX邱ƂAIxݒ\(݂OFF:0 ON:1̂)
;----------------------------------------------------------------

[State -1, AI]@
Type = VarSet
TriggerAll = Var(59) >= 1@@@@ GAI
Trigger1 = RoundState >= 3 @@G퓬varXCb`؂B
V = 59
Value = 0

;
;ȉAȂ
;

[State -1, ^bOp];
Type = VarSet
triggerall = var(59)
trigger1 = RoundState = 2
var(52) = 0 + (NumEnemy = 2 && EnemyNear(var(52)),life <= 0)
IgnoreHitPause = 1

;
;
;
;Ȃ
;
;؂Ԃ⊄荞݁Ao[TȂ
;

;obNXebvEƍU
[State -1]
type = ChangeState
value = 105
TriggerAll = var(59) > 0
TriggerAll = RoundState = 2
TriggerAll = EnemyNear(var(52)),StateType != L
TriggerAll = StateNo != [100,106]
triggerAll = statetype = S
triggerAll = ctrl
TriggerAll = BackEdgeBodyDist > 50
TriggerAll = Random < 250
Trigger1 = InGuardDist && P2BodyDist X = [45,65]
Trigger1 = EnemyNear(var(52)),Time > 8
Trigger2 = EnemyNear(var(52)),HitDefAttr = SCA,NT,ST,HT ;

;---------------------------------------------------------------------------
;Ȃ
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;g
;---------------------------------------------------------------------------
[State -1,󂯗]
type = ChangeState
value = 900
TriggerAll = var(59) > 0
triggerAll = var(58) = 0
TriggerAll = RoundState = 2
triggerall = statetype != A
triggerall = P2StateNo != [120,179]
trigger1 = ctrl
trigger1 = p2bodydist X = [-40,70]
trigger1 = P2BodyDist Y = [-75,0]
trigger1 = Random < 50
;G_bVŐڋ߂ė
trigger2 = EnemyNear(Var(52)),prevstateno = [100,104]
trigger2 = EnemyNear(Var(52)),Vel X >= 0 && EnemyNear(Var(52)),time = [1,2]
trigger2 = (p2bodydist X <= 80 && EnemyNear(Var(52)),Vel X > 0) || p2bodydist X <= 40
trigger2 = Random < 50


;-----------------------------------
;荞݂Ԃρiߋj
;-----------------------------------

[State -1, VA]
type = ChangeState
value = 2300
TriggerAll = var(59) > 0
triggerAll = var(58) = 0
triggerall = power >= 2000
triggerall = statetype != A
TriggerAll = Alive
TriggerAll = RoundState = 2
TriggerAll = P2MoveType = A
;Ԃϋʏ
TriggerAll = (Ctrl)
TriggerAll = (P2Dist Y > -80)
TriggerAll = P2BodyDist X < 50
;̗͂鎞
trigger1 = Life > LifeMax*0.5
trigger1 = power >= 2700
Trigger1 = Random < 150
;̗͌
trigger2 = Life <= LifeMax*0.5
trigger2 = power >= 2300
Trigger2 = Random < 300

[State -1, Aa]
type = ChangeState
value = 2200
TriggerAll = var(59) > 0
triggerAll = var(58) = 0
triggerall = power >= 1000
triggerall = statetype != A
TriggerAll = Alive
TriggerAll = RoundState = 2
TriggerAll = P2MoveType = A
;Ԃϋʏ
TriggerAll = (Ctrl)
TriggerAll = P2statetype != A
TriggerAll = P2BodyDist X < 100
;̗͂鎞
trigger1 = Life > LifeMax*0.5
trigger1 = power >= 1700
Trigger1 = Random < 150
;̗͌
trigger2 = Life <= LifeMax*0.5
trigger2 = power >= 1300
Trigger2 = Random < 300

;-----------------------------------
;荞݂Ԃρij
;-----------------------------------
[State -1, Va]
type = ChangeState
value = 3200
TriggerAll = var(59) > 0
triggerAll = var(58) = 0
triggerall = power >= 4000
triggerall = statetype != A
TriggerAll = Alive
TriggerAll = RoundState = 2
TriggerAll = P2MoveType = A
;Ԃϋʏ
TriggerAll = (Ctrl)
;̗͂鎞
trigger1 = Life > LifeMax*0.5
Trigger1 = Random < 200
;̗͌
trigger2 = Life <= LifeMax*0.5
Trigger2 = Random < 300


[State -1, ]
type = ChangeState
value = 3100
TriggerAll = var(59) > 0
triggerAll = var(58) = 0
triggerall = power >= 3000
triggerall = statetype != A
TriggerAll = Alive
TriggerAll = RoundState = 2
TriggerAll = P2MoveType = A
;Ԃϋʏ
TriggerAll = (Ctrl)
;̗͂鎞
trigger1 = Life > LifeMax*0.5
trigger1 = power >= 3500
Trigger1 = Random < 200
;̗͌
trigger2 = Life <= LifeMax*0.5
Trigger2 = Random < 300


;
;R{Lq
;
;====================================================================================
;sϐ Zbg
;====================================================================================
[State -1,reset1]
type = varset
triggerall = var(58)
trigger1 = p2movetype != H || p2statetype = L
;trigger1 = (var(58) != [2,4]) || (var(58) != [41,44])
;rōUH璆f
trigger2 = statetype = L || movetype = H
;R{󂩂āA肪Ă悤Ȃ璆i
trigger3 = P2stateno=[10,110] 
Trigger4 = !Alive
var(58) = 999

[State -1,reset]
type = varset
trigger1 = var(58) = 999
var(58) = 0


;====================================================================================
;{R{@1-
;====================================================================================
;====================================================================================
;Aqbg
;====================================================================================
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
trigger1 = movehit
trigger1 = stateno = 200
var(58) = 1

;====================================================================================
;Uqbg
;====================================================================================
;Ag͌qɂ̂ŒŕKEZ
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
trigger1 = movehit
trigger1 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger1 = power < 1000
var(58) = 3

[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
trigger1 = movehit
trigger1 = Stateno = 400 || Stateno = 410 || Stateno = 430
trigger1 = power >= 1000
var(58) = 11



;====================================================================================
;̗Eqbg
;====================================================================================
;
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
trigger1 = movehit
trigger1 = stateno = 230
var(58) = 2

;iQ[WȂj
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
trigger1 = movehit
trigger1 = stateno = 210
trigger1 = power < 1000
var(58) = 3

;iQ[Wj
[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
trigger1 = movehit
trigger1 = stateno = 210
trigger1 = power >= 1000
var(58) = 11


;====================================================================================
;ȉAR{̋Lq
;====================================================================================

;
[State -1, Stand Light Kick]
type = ChangeState
value = 230
TriggerAll = var(59) != 0
triggerAll = movehit
triggerAll = var(58) = 1
triggerAll = statetype != A
trigger1 = (stateno = 200) && time > 4
trigger1 = var(58) := 2

;
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
TriggerAll = var(59) != 0
triggerAll = movehit
triggerAll = statetype != A
;Q[WȂ͋_u
trigger1 = var(58) = 2
trigger1 = power < 1000
trigger1 = (stateno = 230) && time > 12
trigger1 = var(58) := 3
;Q[W鎞͎_u璴K
trigger2 = var(58) = 2
trigger2 = power >= 1000
trigger2 = (stateno = 230) && time > 12
trigger2 = var(58) := 11

;====================================================================================
;Eʂ̒
;====================================================================================

[State -1,_uA^bNR]
type = ChangeState
value = 1110
TriggerAll = var(59) != 0
triggerAll = movehit
triggerAll = statetype != A
trigger1 = var(58) = 3
trigger1 = moveHit
trigger1 = var(58) := 999

[State -1,_uA^bN]
type = ChangeState
value = 1100
TriggerAll = var(59) != 0
triggerAll = movehit
triggerAll = statetype != A
triggerAll = var(58) = 11
triggerAll = moveHit
;1Q[W
trigger1 = power = [1000, 1999]
trigger1 = var(58) := 12
;2Q[Wȏ
trigger2 = power >= 2000
trigger2 = var(58) := 14


[State -1, Aa]
type = ChangeState
value = 2200
TriggerAll = var(59) != 0
triggerall = power >= 1000
triggerAll = movehit
triggerAll = statetype != A
;1Q[W
trigger1 = var(58) = 12
trigger1 = Stateno = [1000,1150]
trigger1 = moveHit
trigger1 = var(58) := 999


[State -1, VA]
type = ChangeState
value = 2300
TriggerAll = var(59) != 0
triggerall = power >= 2000
triggerAll = movehit
triggerAll = statetype != A
;1Q[W
trigger1 = var(58) = 14
trigger1 = Stateno = [1000,1150]
trigger1 = moveHit
trigger1 = var(58) := 999


;====================================================================================
;󒆃R{
;====================================================================================

[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
trigger1 = movehit
trigger1 = stateno = 600
var(58) = 51

[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
trigger1 = movehit
trigger1 = stateno = 610
var(58) = 52

;
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
TriggerAll = var(59) != 0
triggerAll = movehit
triggerAll = var(58) = 51
trigger1 = statetype = A
trigger1 = var(58) := 52

;
[State -1, Jump Light Kick]
type = ChangeState
value = 630
TriggerAll = var(59) != 0
triggerAll = movehit
triggerAll = var(58) = 52
trigger1 = statetype = A
trigger1 = var(58) := 999


;====================================================================================
;̋Zqbg
;====================================================================================

[State -1,R{ڍsp]
type = varset
TriggerAll = var(59) != 0
triggerAll = var(58) = 0
trigger1 = movehit
trigger1 = stateno = 1150
var(58) = 101


[State -1, VA]
type = ChangeState
value = 2300
TriggerAll = var(59) != 0
triggerAll = var(58) = 101
triggerall = power >= 2000
triggerall = statetype != A
trigger1 = var(58) := 999


[State -1,CWO\[h]
type = ChangeState
value = 1200
TriggerAll = var(59) != 0
triggerAll = var(58) = 101
triggerall = statetype != A
trigger1 = ctrl
trigger1 = var(58) := 999


;
;K[hLq
;

;K[h̓Kb`K`
[State -3]
Type = VarSet
TriggerAll = var(57) = 0
Trigger1 = EnemyNear,NumHelper > 0
trigger1 = RoundState = 2
V = 57
Value = EnemyNear,NumHelper

[State -3,]
Type = ChangeState
Value = 120
triggerall = RoundState = 2
triggerAll = Var(59) >= 1
triggerAll = Ctrl
trigger1 = InGuardDist
trigger1 =! EnemyNear,HitDefAttr = ,NT,ST,HT 
trigger2 = Enemy,NumHelper > 0
trigger2 = Enemy,NumHelper > var(57)
trigger2 = InGuardDist




;
;΋ENU߁EԂςȂ
;

;====================================================================================
;΋
;====================================================================================
[State -1,CWO\[h]
type = ChangeState
value = 1200
TriggerAll = var(59) > 0
triggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = ctrl
trigger1 = P2Dist Y = [-1,-100]
trigger1 = P2BodyDist X < 75
trigger1 = Random < 100



;====================================================================================
;NU
;====================================================================================

;====================================================================================
;Ԃ
;====================================================================================
[State -1, Va]
type = ChangeState
value = 3200
TriggerAll = var(59) > 0
triggerAll = var(58) = 0
triggerall = power >= 4000
triggerall = statetype != A
TriggerAll = Alive
TriggerAll = RoundState = 2
;Ԃϋʏ
TriggerAll = (Ctrl)
;̗͂鎞
trigger1 = Life > LifeMax*0.5
Trigger1 = Random < 15
;̗͌
trigger1 = Life <= LifeMax*0.5
Trigger1 = Random < 50


[State -1, ]
type = ChangeState
value = 3100
TriggerAll = var(59) > 0
triggerAll = var(58) = 0
triggerall = power >= 3000
triggerall = statetype != A
TriggerAll = Alive
TriggerAll = RoundState = 2
;Ԃϋʏ
TriggerAll = (Ctrl)
;̗͂鎞
trigger1 = Life > LifeMax*0.5
trigger1 = power >= 3700
Trigger1 = Random < 15
;̗͌
trigger1 = Life <= LifeMax*0.5
trigger1 = power >= 3500
Trigger1 = Random < 50


;
;ړs
;
;3Q[Wȏ゠ΑOցH
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
triggerall = power >= 3000
;
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = P2BodyDist X > 200
Trigger1 = Random < 100
;
trigger2 = statetype != A
trigger2 = ctrl
trigger2 = P2BodyDist X > 150
Trigger2 = Random < 75
;ߋ
trigger3 = statetype != A
trigger3 = ctrl
trigger3 = P2BodyDist X > 100
Trigger3 = Random < 35


;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = RoundState = 2
trigger1 = statetype != A
trigger1 = ctrl
Trigger1 = EnemyNear(Var(52)),StateType = L
trigger1 = FrontEdgeDist <= 140

;ƂQ[W
;Q[W
[State -1, Taunt]
type = ChangeState
value = 196
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
triggerall = RoundState = 2
triggerall = statetype != A
triggerall = Power < 4000
triggerall = ctrl
Triggerall = !InGuardDist
trigger1 = p2bodydist X >100
trigger1 = random < 50
trigger2 = p2bodydist X >160
trigger2 = random < 100


;
;Z
;
;====================================================================================
;ߋ -40
;====================================================================================
;
[State -1, Stand Light Punch]
type = ChangeState
value = 200
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 40
Trigger1 = P2BodyDist Y = [-60,0]
Trigger1 = Random < 200

;Ⴊݎ
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 40
Trigger1 = P2StateType != A
Trigger1 = Random < 200

;Ⴊݒ
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X = [30, 45]
Trigger1 = P2StateType != A
Trigger1 = Random < 75

;
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X = [35, 60]
Trigger1 = P2BodyDist Y = [-80,0]
Trigger1 = Random < 75


;Ⴊ݋
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
;𓖂Ă
trigger1 = ctrl
Trigger1 = P2BodyDist X = [35, 50]
Trigger1 = P2StateType != A
Trigger1 = Random < 75
;c𓖂Ă
trigger2 = ctrl
Trigger2 = P2BodyDist X <= 30
trigger2 = P2statetype = A
Trigger2 = P2BodyDist Y = [-50,0]
Trigger2 = Random < 100


[State -1,_uA^bN]
type = ChangeState
value = 1100
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 40
Trigger1 = P2StateType != A
Trigger1 = EnemyNear(fvar(12)),StateType != L
Trigger1 = Random < 100

[State -1,_uA^bNR]
type = ChangeState
value = 1120
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = ctrl
Trigger1 = P2BodyDist X <= 30
Trigger1 = P2StateType != A
Trigger1 = EnemyNear(fvar(12)),StateType != L
Trigger1 = Random < 100

[State -1,_uA^bNQ]
type = ChangeState
value = 1110
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = (Ctrl)
Trigger1 = P2BodyDist X <= 50
Trigger1 = P2BodyDist Y = [-100,0]
Trigger1 = Random <= 100

;---------------------------------------------------------------------------
;oxK[sipxj肪Uɂ͏oȂ
;---------------------------------------------------------------------------
[State -1,o[XgNbV]
type = ChangeState
value = 1150
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = (Ctrl)
Trigger1 = P2MoveType != A
Trigger1 = P2BodyDist X <= 50
Trigger1 = P2BodyDist Y = [-75,0]
Trigger1 = Random <= 50


;-----------------------------------
;΋
;-----------------------------------
;󒆎
[State -1, Jump Light Punch]
type = ChangeState
value = 600
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
TriggerAll = statetype = A
trigger1 = ctrl
Trigger1 = P2BodyDist Y = [-15, 15]
trigger1 = P2BodyDist X < 30
Trigger1 = Random < 100

;󒆒
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
TriggerAll = statetype = A
trigger1 = ctrl
Trigger1 = P2BodyDist Y = [-20, 20]
trigger1 = P2BodyDist X = [30, 75]
Trigger1 = Random < 100

;󒆋
[State -1, Jump Light Kick]
type = ChangeState
value = 630
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
TriggerAll = statetype = A
trigger1 = ctrl
Trigger1 = P2BodyDist Y = [-100, 50]
trigger1 = P2BodyDist X = [0, 60]
Trigger1 = Random < 150


;====================================================================================
;ߋ -75
;====================================================================================
;
[State -1, Stand Light Kick]
type = ChangeState
value = 230
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = (Ctrl)
Trigger1 = P2BodyDist X = [25, 75]
Trigger1 = P2StateType != A
Trigger1 = Random <= 200


[State -1,ECh]
type = ChangeState
value = 1000
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = (Ctrl)
Trigger1 = P2BodyDist X = [40, 75]
Trigger1 = P2BodyDist Y = [-75,0]
Trigger1 = Random <= 100



;====================================================================================
; 100-
;====================================================================================
[State -1,\jbNGbW]
type = ChangeState
value = 1050
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = (Ctrl)
trigger1 = P2BodyDist X >= 100
Trigger1 = Random <= 200


[State -1,ECh]
type = ChangeState
value = 1010
TriggerAll = var(59) > 0
TriggerAll = var(58) = 0
TriggerAll = Alive
TriggerAll = RoundState = 2
triggerAll = statetype != A
trigger1 = (Ctrl)
Trigger1 = P2BodyDist X = [100, 150]
Trigger1 = P2BodyDist Y = [-75,0]
Trigger1 = Random <= 150



